@@ -19,7 +19,7 @@ var searchData=
   ['bestrowscope_2eidl_16',['BestRowScope.idl',['../BestRowScope_8idl.html',1,'']]],
   ['bestrowtype_2eidl_17',['BestRowType.idl',['../BestRowType_8idl.html',1,'']]],
   ['bezierpoint_2eidl_18',['BezierPoint.idl',['../BezierPoint_8idl.html',1,'']]],
-  ['bibliography_2eidl_19',['Bibliography.idl',['../frame_2Bibliography_8idl.html',1,'(Global Namespace)'],['../text_2fieldmaster_2Bibliography_8idl.html',1,'(Global Namespace)'],['../text_2textfield_2Bibliography_8idl.html',1,'(Global Namespace)'],['../text_2Bibliography_8idl.html',1,'(Global Namespace)']]],
+  ['bibliography_2eidl_19',['Bibliography.idl',['../text_2textfield_2Bibliography_8idl.html',1,'(Global Namespace)'],['../frame_2Bibliography_8idl.html',1,'(Global Namespace)'],['../text_2Bibliography_8idl.html',1,'(Global Namespace)'],['../text_2fieldmaster_2Bibliography_8idl.html',1,'(Global Namespace)']]],
   ['bibliographydatafield_2eidl_20',['BibliographyDataField.idl',['../BibliographyDataField_8idl.html',1,'']]],
   ['bibliographydatatype_2eidl_21',['BibliographyDataType.idl',['../BibliographyDataType_8idl.html',1,'']]],
   ['bindablecontrolmodel_2eidl_22',['BindableControlModel.idl',['../BindableControlModel_8idl.html',1,'']]],
